@@ -3,11 +3,10 @@ import os
 
 from flask_migrate import Migrate
 from flask_script import Manager, Shell
-
-from app import create_app, db
-from datas.model.cron_infos import CronInfos
-from datas.model.job_log import JobLog
-from datas.model.job_log_items import JobLogItems
+from notejob.center.app import create_app, db
+from notejob.center.datas.model.cron_infos import CronInfos
+from notejob.center.datas.model.job_log import JobLog
+from notejob.center.datas.model.job_log_items import JobLogItems
 
 app = create_app(os.getenv('FLASK_CONFIG') or 'default')
 
